@@ -1,25 +1,16 @@
 /*
-    Copyright (c) 2010 Grégory Oestreicher <greg@kamago.net>
-    Based on DavItemsListJob which is copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2010 Grégory Oestreicher <greg@kamago.net>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
+    Based on DavItemsListJob:
+    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KDAV_DAVITEMSFETCHJOB_H
 #define KDAV_DAVITEMSFETCHJOB_H
 
-#include "kpimkdav_export.h"
+#include "kdav_export.h"
 
 #include "davitem.h"
 #include "davjobbase.h"
@@ -34,7 +25,7 @@ class DavItemsFetchJobPrivate;
 /**
  * @short A job that fetches a list of items from a DAV server using a multiget query.
  */
-class KPIMKDAV_EXPORT DavItemsFetchJob : public DavJobBase
+class KDAV_EXPORT DavItemsFetchJob : public DavJobBase
 {
     Q_OBJECT
 
