@@ -1,24 +1,13 @@
 /*
-    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KDAV_DAVURL_H
 #define KDAV_DAVURL_H
 
-#include "kpimkdav_export.h"
+#include "kdav_export.h"
 
 #include "enums.h"
 
@@ -31,7 +20,7 @@ class DavUrlPrivate;
 /**
  * @short A helper class to combine url and protocol of a DAV url.
  */
-class KPIMKDAV_EXPORT DavUrl
+class KDAV_EXPORT DavUrl
 {
 public:
     /**
@@ -84,8 +73,8 @@ private:
     QSharedDataPointer<DavUrlPrivate> d;
 };
 
-KPIMKDAV_EXPORT QDataStream &operator<<(QDataStream &out, const DavUrl &url);
-KPIMKDAV_EXPORT QDataStream &operator>>(QDataStream &in, DavUrl &url);
+KDAV_EXPORT QDataStream &operator<<(QDataStream &out, const DavUrl &url);
+KDAV_EXPORT QDataStream &operator>>(QDataStream &in, DavUrl &url);
 }
 
 Q_DECLARE_TYPEINFO(KDAV::DavUrl, Q_MOVABLE_TYPE);
